import { renderless, api } from '@opentinyvue/vue-renderless/time-spinner/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import Scrollbar from '@opentinyvue/vue-scrollbar';
import { RepeatClick } from '@opentinyvue/vue-directive';
import { IconChevronDown, IconChevronUp } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "wrapper": "max-h-[270px] overflow-hidden flex-1 align-top relative",
  "is-arrow": "left-0 box-border text-center overflow-hidden",
  "list": "translate-y-[110px] p-0 m-0 list-none text-center after:content-[''] after:block after:h-[100px] after:w-full",
  "item": "text-sm text-color-text-primary h-12 w-12 py-1 cursor-pointer mx-auto my-0",
  "text": "rounded my-0 flex items-center justify-center h-full hover:bg-color-bg-2",
  "arrow": "text-xs text-color-text-placeholder h-3 leading-3 absolute left-0 w-full z-[1] text-center cursor-pointer",
  "active": "bg-color-fill-6 hover:bg-color-fill-6 text-color-brand",
  "disabled": "text-color-text-placeholder cursor-not-allowed bg-transparent hover:bg-transparent"
};
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["flex", {
      "has-seconds": _vm.showSeconds
    }],
    attrs: {
      "data-tag": "tiny-time-spinner"
    }
  }, [!_vm.arrowControl ? [_c("tiny-scrollbar", {
    ref: "hours",
    class: [_vm.gcls("wrapper"), _vm.state.animationName],
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper",
      "wrap-style": "max-height: inherit;",
      "data-view-class": "tiny-time-spinner__list",
      "view-class": _vm.gcls("list"),
      "noresize": "",
      "tag": "div"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("hours");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("hours");
      }
    }
  }, _vm._l(_vm.state.hoursList, function(_ref) {
    var _vm$m;
    var disabled = _ref.disabled, hour = _ref.hour;
    return _c("div", {
      key: hour,
      class: [_vm.gcls("item")],
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("hours", {
            value: hour,
            disabled
          });
        }
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m = {}, _vm$m[_vm.gcls("active")] = hour === _vm.state.hours, _vm$m[_vm.gcls("disabled")] = disabled, _vm$m))
    }, [_vm._v(_vm._s(("0" + (_vm.amPmMode ? hour % 12 || 12 : hour)).slice(-2)) + _vm._s(_vm.amPm(hour)))])]);
  }), 0), _c("tiny-scrollbar", {
    ref: "minutes",
    class: [_vm.gcls("wrapper"), _vm.state.animationName + "-up"],
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper",
      "wrap-style": "max-height: inherit;",
      "data-view-class": "tiny-time-spinner__list",
      "view-class": _vm.gcls("list"),
      "noresize": "",
      "tag": "div"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("minutes");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("minutes");
      }
    }
  }, _vm._l(_vm.state.minutesList, function(_ref2) {
    var _vm$m2;
    var disabled = _ref2.disabled, minute = _ref2.minute;
    return _c("div", {
      key: minute,
      class: [_vm.gcls("item")],
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("minutes", {
            value: minute,
            disabled: false
          });
        }
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m2 = {}, _vm$m2[_vm.gcls("active")] = minute === _vm.state.minutes, _vm$m2[_vm.gcls("disabled")] = !disabled, _vm$m2))
    }, [_vm._v(_vm._s(("0" + minute).slice(-2)))])]);
  }), 0), _c("tiny-scrollbar", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.showSeconds,
      expression: "showSeconds"
    }],
    ref: "seconds",
    class: [_vm.gcls("wrapper"), _vm.state.animationName],
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper",
      "wrap-style": "max-height: inherit;",
      "data-view-class": "tiny-time-spinner__list",
      "view-class": _vm.gcls("list"),
      "noresize": "",
      "tag": "div"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("seconds");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("seconds");
      }
    }
  }, _vm._l(_vm.state.secondsList, function(_ref3) {
    var _vm$m3;
    var second = _ref3.second;
    return _c("div", {
      key: second,
      class: [_vm.gcls("item")],
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("seconds", {
            value: second,
            disabled: false
          });
        }
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m3 = {}, _vm$m3[_vm.gcls("active")] = second === _vm.state.seconds, _vm$m3))
    }, [_vm._v(_vm._s(("0" + second).slice(-2)))])]);
  }), 0)] : _vm._e(), _vm.arrowControl ? [_c("div", {
    class: _vm.gcls(["wrapper", "is-arrow"]),
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper is-arrow"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("hours");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-up"
    }
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-down"
    }
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "hours",
    class: [_vm.state.animationName],
    attrs: {
      "data-tag": "tiny-time-spinner__list"
    }
  }, _vm._l(_vm.state.arrowHourList, function(hour, key) {
    var _vm$m4;
    return _c("div", {
      key,
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m4 = {}, _vm$m4[_vm.gcls("active")] = hour === _vm.state.hours, _vm$m4[_vm.gcls("disabled")] = _vm.state.hoursList.find(function(item) {
        return item.hour === hour;
      }) && _vm.state.hoursList.find(function(item) {
        return item.hour === hour;
      }).disabled, _vm$m4))
    }, [_vm._v(_vm._s(hour === void 0 ? "" : ("0" + (_vm.amPmMode ? hour % 12 || 12 : hour)).slice(-2) + _vm.amPm(hour)))])]);
  }), 0)]), _c("div", {
    class: _vm.gcls(["wrapper", "is-arrow"]),
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper is-arrow"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("minutes");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-up"
    }
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-down"
    }
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "minutes",
    class: [_vm.state.animationName + "-up"],
    attrs: {
      "data-tag": "tiny-time-spinner__list"
    }
  }, _vm._l(_vm.state.arrowMinuteList, function(minute, key) {
    var _vm$m5;
    return _c("div", {
      key,
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m5 = {}, _vm$m5[_vm.gcls("active")] = minute === _vm.state.minutes, _vm$m5))
    }, [_vm._v(_vm._s(minute === void 0 ? "" : ("0" + minute).slice(-2)))])]);
  }), 0)]), _vm.showSeconds ? _c("div", {
    class: _vm.gcls(["wrapper", "is-arrow"]),
    attrs: {
      "data-tag": "tiny-time-spinner__wrapper is-arrow"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("seconds");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-up"
    }
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    attrs: {
      "data-tag": "tiny-time-spinner__arrow tiny-icon-arrow-down"
    }
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "seconds",
    class: [_vm.state.animationName],
    attrs: {
      "data-tag": "tiny-time-spinner__list"
    }
  }, _vm._l(_vm.state.arrowSecondList, function(second, key) {
    var _vm$m6;
    return _c("div", {
      key,
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", {
      class: _vm.m(_vm.gcls("text"), (_vm$m6 = {}, _vm$m6[_vm.gcls("active")] = second === _vm.state.seconds, _vm$m6))
    }, [_vm._v(_vm._s(second === void 0 ? "" : ("0" + second).slice(-2)))])]);
  }), 0)]) : _vm._e()] : _vm._e()], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  emits: ["change", "select-range"],
  components: {
    TinyScrollbar: Scrollbar,
    IconChevronDown: IconChevronDown(),
    IconChevronUp: IconChevronUp()
  },
  directives: directive({
    repeatClick: {
      bind: RepeatClick
    }
  }),
  props: [].concat(props, ["date", "defaultValue", "showSeconds", "arrowControl", "amPmMode", "step"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
