import { renderless, api } from '@opentinyvue/vue-renderless/time-spinner/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import Scrollbar from '@opentinyvue/vue-scrollbar';
import { RepeatClick } from '@opentinyvue/vue-directive';
import { iconChevronDown, iconChevronUp } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["change", "select-range"],
  components: {
    TinyScrollbar: Scrollbar,
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp()
  },
  directives: directive({
    repeatClick: {
      bind: RepeatClick
    }
  }),
  props: [].concat(props, ["date", "defaultValue", "showSeconds", "arrowControl", "amPmMode", "step", "startDate", "endDate"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-time-spinner",
    class: {
      "has-seconds": _vm.showSeconds
    }
  }, [!_vm.arrowControl ? [_c("tiny-scrollbar", {
    ref: "hours",
    staticClass: "tiny-time-spinner__wrapper",
    class: [_vm.state.animationName],
    attrs: {
      "wrap-style": "max-height: inherit;",
      "view-class": "tiny-time-spinner__list",
      "noresize": "",
      "tag": "ul"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("hours");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("hours");
      }
    }
  }, _vm._l(_vm.state.hoursList, function(_ref) {
    var disabled = _ref.disabled, hour = _ref.hour;
    return _c("li", {
      key: hour,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: hour === _vm.state.hours,
        disabled
      },
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("hours", {
            value: hour,
            disabled
          });
        }
      }
    }, [_c("span", [_vm._v(_vm._s(("0" + (_vm.amPmMode ? hour % 12 || 12 : hour)).slice(-2)) + _vm._s(_vm.amPm(hour)))])]);
  }), 0), _c("tiny-scrollbar", {
    ref: "minutes",
    staticClass: "tiny-time-spinner__wrapper",
    class: [_vm.state.animationName + "-up"],
    attrs: {
      "wrap-style": "max-height: inherit;",
      "view-class": "tiny-time-spinner__list",
      "noresize": "",
      "tag": "ul"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("minutes");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("minutes");
      }
    }
  }, _vm._l(_vm.state.minutesList, function(_ref2) {
    var disabled = _ref2.disabled, minute = _ref2.minute;
    return _c("li", {
      key: minute,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: minute === _vm.state.minutes,
        disabled: !disabled
      },
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("minutes", {
            value: minute,
            disabled: false
          });
        }
      }
    }, [_c("span", [_vm._v(_vm._s(("0" + minute).slice(-2)))])]);
  }), 0), _c("tiny-scrollbar", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.showSeconds,
      expression: "showSeconds"
    }],
    ref: "seconds",
    staticClass: "tiny-time-spinner__wrapper",
    class: [_vm.state.animationName],
    attrs: {
      "wrap-style": "max-height: inherit;",
      "view-class": "tiny-time-spinner__list",
      "noresize": "",
      "tag": "ul"
    },
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("seconds");
      },
      "mousemove": function mousemove($event) {
        return _vm.adjustCurrentSpinner("seconds");
      }
    }
  }, _vm._l(_vm.state.secondsList, function(_ref3) {
    var second = _ref3.second;
    return _c("li", {
      key: second,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: second === _vm.state.seconds
      },
      attrs: {
        "data-tag": "li"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClick("seconds", {
            value: second,
            disabled: false
          });
        }
      }
    }, [_c("span", [_vm._v(_vm._s(("0" + second).slice(-2)))])]);
  }), 0)] : _vm._e(), _vm.arrowControl ? [_c("div", {
    staticClass: "tiny-time-spinner__wrapper is-arrow",
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("hours");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-up"
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-down"
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "hours",
    staticClass: "tiny-time-spinner__list",
    class: [_vm.state.animationName]
  }, _vm._l(_vm.state.arrowHourList, function(hour, key) {
    return _c("li", {
      key,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: hour === _vm.state.hours,
        disabled: _vm.state.hoursList.find(function(item) {
          return item.hour === hour;
        }) && _vm.state.hoursList.find(function(item) {
          return item.hour === hour;
        }).disabled
      },
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", [_vm._v(_vm._s(hour === void 0 ? "" : ("0" + (_vm.amPmMode ? hour % 12 || 12 : hour)).slice(-2) + _vm.amPm(hour)))])]);
  }), 0)]), _c("div", {
    staticClass: "tiny-time-spinner__wrapper is-arrow",
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("minutes");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-up"
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-down"
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "minutes",
    staticClass: "tiny-time-spinner__list",
    class: [_vm.state.animationName + "-up"]
  }, _vm._l(_vm.state.arrowMinuteList, function(minute, key) {
    return _c("li", {
      key,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: minute === _vm.state.minutes
      },
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", [_vm._v(_vm._s(minute === void 0 ? "" : ("0" + minute).slice(-2)))])]);
  }), 0)]), _vm.showSeconds ? _c("div", {
    staticClass: "tiny-time-spinner__wrapper is-arrow",
    on: {
      "mouseenter": function mouseenter($event) {
        return _vm.emitSelectRange("seconds");
      }
    }
  }, [_c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-up"
  }, [_c("icon-chevron-up")], 1), _c("i", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-time-spinner__arrow tiny-icon-arrow-down"
  }, [_c("icon-chevron-down")], 1), _c("ul", {
    ref: "seconds",
    staticClass: "tiny-time-spinner__list",
    class: [_vm.state.animationName]
  }, _vm._l(_vm.state.arrowSecondList, function(second, key) {
    return _c("li", {
      key,
      staticClass: "tiny-time-spinner__item",
      class: {
        active: second === _vm.state.seconds
      },
      attrs: {
        "data-tag": "li"
      }
    }, [_c("span", [_vm._v(_vm._s(second === void 0 ? "" : ("0" + second).slice(-2)))])]);
  }), 0)]) : _vm._e()] : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
